2023-08-10 Version: 1.0.6
- Generated python2 2017-12-25 for OpenSearch.

2022-03-30 Version: 1.0.5
- Update algorithm service interface.

2022-03-29 Version: 1.0.4
- Add algorithm service interface.

2021-12-31 Version: 1.0.3
- Add algorithm service interface.

